# Suggestions d'amélioration pour les traductions de la documentation

Merci pour votre intérêt pour ce projet ! La documentation non-anglaise est automatiquement traduite par des modèles de langage volumineux, donc des erreurs sont inévitables. Si vous remarquez des problèmes dans une langue que vous maîtrisez, nous vous encourageons vivement à soumettre vos suggestions d'amélioration.

Avant de commencer à contribuer, veuillez prendre un moment pour lire le guide suivant afin de vous assurer que vos suggestions puissent être acceptées sans problème.

# Soumettre des suggestions via Weblate

Nous utilisons [Weblate](https://weblate.org/) pour gérer les traductions de notre documentation. Vous pouvez consulter l'état actuel des traductions et soumettre des suggestions sur la [page Weblate du projet](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

## Comment soumettre une suggestion

Il est très simple de proposer des améliorations de traduction via Weblate, et vous n'avez même pas besoin de créer un compte. Lisez la suite pour connaître le processus étape par étape.

Supposons que vous souhaitiez améliorer la première phrase de la section "命令行参数" dans [高级选项 → 高级](docs/en/advanced/advanced.md) :

1. Ouvrez la [page Weblate du projet](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

2. Cliquez sur `Search` en haut.

<img src="./../../images/weblate/homepage.png" width="420px" alt="homepage"/>

3. Dans "Filtre", entrez le segment de texte que vous souhaitez trouver. Un texte partiel est acceptable.

<img src="./../../images/weblate/search.png" alt="search"/>

Lorsque vous avez terminé, appuyez sur <kbd>Entrée</kbd>.

4. Après avoir appuyé sur <kbd>Entrée</kbd>, vous serez redirigé vers la page des résultats de recherche. Cliquez sur le résultat que vous préférez pour ouvrir la vue d'édition.

<img src="./../../images/weblate/search-result.png" alt="search result"/>

5. Dans la vue d'édition, apportez vos modifications à la traduction. Une fois terminé, cliquez sur <kbd>Suggérer</kbd>. C'est tout—vous avez réussi à effectuer une contribution.

<img src="./../../images/weblate/suggestion.png" alt="suggestion"/>

Nous examinerons votre suggestion après sa soumission. Une fois approuvée, vos modifications apparaîtront dans la documentation.

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>